@@ -5,11 +5,9 @@
 #  License: See LICENSE.txt
 #
 
-
 import logging
 from beets import config as beets_global_config
 from beets.util.confit import Subview
-from collections import OrderedDict
 from beets.random import random_objs
 
 MUST_HAVE_TRAINING_KEYS = ['song_bpm', 'song_len', 'duration', 'target']
@@ -30,8 +28,8 @@ def get_human_readable_time(seconds):
 
 
 def get_config_value_bubble_up(cfg_view: Subview, attrib: str):
-    """
-    Method that will ''bubble up'' in the configuration hierarchy to find the value of the requested attribute
+    """This method will look for the requested attribute in the provided view
+    all the way up the hierarchy tree until it finds it (or hits the root).
     """
     value = None
 
@@ -67,12 +65,13 @@ def get_duration_of_items(items):
 
 def get_randomized_items(items, duration_min):
     """ This randomization and limiting to duration_min is very basic
-    @todo: after randomization select songs to be as close as possible to the duration_min (+-5seconds)
+    @todo: after randomization select songs to be as close as possible to the
+    duration_min (+-5seconds)
     """
     r_limit = 1
     r_time_minutes = duration_min
     r_equal_chance = True
-    rnd_items = random_objs(list(items), False, r_limit, r_time_minutes, r_equal_chance)
+    rnd_items = random_objs(list(items), False, r_limit, r_time_minutes,
+                            r_equal_chance)
 
     return rnd_items
-
